oriole_service.cli package
==========================

Submodules
----------

oriole_service.cli.doc module
-----------------------------

.. automodule:: oriole_service.cli.doc
    :members:
    :undoc-members:
    :show-inheritance:

oriole_service.cli.go module
----------------------------

.. automodule:: oriole_service.cli.go
    :members:
    :undoc-members:
    :show-inheritance:

oriole_service.cli.goto module
------------------------------

.. automodule:: oriole_service.cli.goto
    :members:
    :undoc-members:
    :show-inheritance:

oriole_service.cli.main module
------------------------------

.. automodule:: oriole_service.cli.main
    :members:
    :undoc-members:
    :show-inheritance:

oriole_service.cli.run module
-----------------------------

.. automodule:: oriole_service.cli.run
    :members:
    :undoc-members:
    :show-inheritance:

oriole_service.cli.test module
------------------------------

.. automodule:: oriole_service.cli.test
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: oriole_service.cli
    :members:
    :undoc-members:
    :show-inheritance:
